@@ -8,7 +8,6 @@ use std::sync::Arc;
 use std::sync::mpsc::channel;
 use std::thread;
 
-use clap::ValueEnum;
 use crossbeam::channel::{Receiver, Sender};
 use skim_tuikit::prelude::{Event as TermEvent, *};
 
@@ -104,7 +103,7 @@ impl<T: Any> AsAny for T {
 /// ```
 pub trait SkimItem: AsAny + Send + Sync + 'static {
     /// The string to be used for matching (without color)
-    fn text(&self) -> Cow<str>;
+    fn text(&self) -> Cow<'_, str>;
 
     /// The content to be displayed on the item list, could contain ANSI properties
     fn display<'a>(&'a self, context: DisplayContext<'a>) -> AnsiString<'a> {
@@ -121,7 +120,7 @@ pub trait SkimItem: AsAny + Send + Sync + 'static {
     /// Note that this function is intended to be used by the caller of skim and will not be used by
     /// skim. And since skim will return the item back in `SkimOutput`, if string is not what you
     /// want, you could still use `downcast` to retain the pointer to the original struct.
-    fn output(&self) -> Cow<str> {
+    fn output(&self) -> Cow<'_, str> {
         self.text()
     }
 
@@ -147,7 +146,7 @@ pub trait SkimItem: AsAny + Send + Sync + 'static {
 // Implement SkimItem for raw strings
 
 impl<T: AsRef<str> + Send + Sync + 'static> SkimItem for T {
-    fn text(&self) -> Cow<str> {
+    fn text(&self) -> Cow<'_, str> {
         Cow::Borrowed(self.as_ref())
     }
 }
@@ -234,8 +233,9 @@ pub enum ItemPreview {
 //==============================================================================
 // A match engine will execute the matching algorithm
 
-#[derive(ValueEnum, Eq, PartialEq, Debug, Copy, Clone, Default)]
-#[clap(rename_all = "snake_case")]
+#[derive(Eq, PartialEq, Debug, Copy, Clone, Default)]
+#[cfg_attr(feature = "cli", derive(clap::ValueEnum))]
+#[cfg_attr(feature = "cli", clap(rename_all = "snake_case"))]
 pub enum CaseMatching {
     Respect,
     Ignore,
