@@ -1,6 +1,7 @@
 use std::cell::RefCell;
 use std::rc::Rc;
 
+#[cfg(feature = "cli")]
 use clap::Parser;
 use derive_builder::Builder;
 
@@ -82,20 +83,20 @@ use crate::{CaseMatching, FuzzyAlgorithm, Selector};
 #[derive(Builder)]
 #[builder(build_fn(name = "final_build"))]
 #[builder(default)]
-#[derive(Parser)]
-#[command(name = "sk", args_override_self = true, version)]
+#[cfg_attr(feature = "cli", derive(Parser))]
+#[cfg_attr(feature = "cli", command(name = "sk", args_override_self = true, version))]
 pub struct SkimOptions {
     //  --- Search ---
     /// Show results in reverse order
     ///
     /// *Often used in combination with `--no-sort`*
-    #[arg(long, help_heading = "Search")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Search"))]
     pub tac: bool,
 
     /// Minimum query length to start showing results
     ///
     /// Only show results when the query is at least this many characters long
-    #[arg(long, help_heading = "Search")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Search"))]
     pub min_query_length: Option<usize>,
 
     /// Do not sort the results
@@ -103,7 +104,7 @@ pub struct SkimOptions {
     /// *Often used in combination with `--tac`*
     ///
     /// **Example**: `history | sk --tac --no-sort`
-    #[arg(long, help_heading = "Search")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Search"))]
     pub no_sort: bool,
 
     /// Comma-separated list of sort criteria to apply when the scores are tied.
@@ -123,13 +124,16 @@ pub struct SkimOptions {
     ///   * Each criterion could be negated, e.g. (-index)
     ///
     ///   * Each criterion should appear only once in the list
-    #[arg(
-        short,
-        long,
-        default_value = "score,begin,end",
-        value_enum,
-        value_delimiter = ',',
-        help_heading = "Search"
+    #[cfg_attr(
+        feature = "cli",
+        arg(
+            short,
+            long,
+            default_value = "score,begin,end",
+            value_enum,
+            value_delimiter = ',',
+            help_heading = "Search"
+        )
     )]
     pub tiebreak: Vec<RankCriteria>,
 
@@ -155,27 +159,36 @@ pub struct SkimOptions {
     ///   * `..-3`:   From the 1st field to the 3rd to the last field
     ///
     ///   * `..`:     All the fields
-    #[arg(short, long, default_value = "", help_heading = "Search", value_delimiter = ',')]
+    #[cfg_attr(
+        feature = "cli",
+        arg(short, long, default_value = "", help_heading = "Search", value_delimiter = ',')
+    )]
     pub nth: Vec<String>,
 
     /// Fields to be transformed
     ///
     /// See **nth** for the details
-    #[arg(long, default_value = "", help_heading = "Search", value_delimiter = ',')]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long, default_value = "", help_heading = "Search", value_delimiter = ',')
+    )]
     pub with_nth: Vec<String>,
 
     /// Delimiter between fields
     ///
     /// In regex format, default to AWK-style
-    #[arg(short, long, default_value = r"[\t\n ]+", help_heading = "Search")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(short, long, default_value = r"[\t\n ]+", help_heading = "Search")
+    )]
     pub delimiter: String,
 
     /// Run in exact mode
-    #[arg(short, long, help_heading = "Search")]
+    #[cfg_attr(feature = "cli", arg(short, long, help_heading = "Search"))]
     pub exact: bool,
 
     /// Start in regex mode instead of fuzzy-match
-    #[arg(long, help_heading = "Search")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Search"))]
     pub regex: bool,
 
     /// Fuzzy matching algorithm
@@ -185,13 +198,19 @@ pub struct SkimOptions {
     /// * **skim_v1**: Legacy skim algorithm
     ///
     /// * **clangd**: Used in clangd for keyword completion
-    #[arg(long = "algo", default_value = "skim_v2", value_enum, help_heading = "Search")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long = "algo", default_value = "skim_v2", value_enum, help_heading = "Search")
+    )]
     pub algorithm: FuzzyAlgorithm,
 
     /// Case sensitivity
     ///
     /// Determines whether or not to ignore case while matching
-    #[arg(long, default_value = "smart", value_enum, help_heading = "Search")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long, default_value = "smart", value_enum, help_heading = "Search")
+    )]
     pub case: CaseMatching,
 
     //  --- Interface ---
@@ -429,35 +448,38 @@ pub struct SkimOptions {
     ///
     /// If  the query is empty, skim will execute abort action, otherwise execute delete-char action. It
     /// is equal to ‘delete-char/eof‘.
-    #[arg(short, long, help_heading = "Interface", value_delimiter = ',')]
+    #[cfg_attr(feature = "cli", arg(short, long, help_heading = "Interface", value_delimiter = ','))]
     pub bind: Vec<String>,
 
     /// Enable multiple selection
     ///
     /// Uses Tab and S-Tab by default for selection
-    #[arg(short, long, overrides_with = "no_multi", help_heading = "Interface")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(short, long, overrides_with = "no_multi", help_heading = "Interface")
+    )]
     pub multi: bool,
 
     /// Disable multiple selection
-    #[arg(long, conflicts_with = "multi", help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, conflicts_with = "multi", help_heading = "Interface"))]
     pub no_multi: bool,
 
     /// Disable mouse
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub no_mouse: bool,
 
     /// Command to invoke dynamically in interactive mode
     ///
     /// Will be invoked using `sh -c`
-    #[arg(short, long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(short, long, help_heading = "Interface"))]
     pub cmd: Option<String>,
 
     /// Run in interactive mode
-    #[arg(short, long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(short, long, help_heading = "Interface"))]
     pub interactive: bool,
 
     /// Replace replstr with the selected item in commands
-    #[arg(short = 'I', default_value = "{}", help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(short = 'I', default_value = "{}", help_heading = "Interface"))]
     pub replstr: String,
 
     /// Set color theme
@@ -506,17 +528,17 @@ pub struct SkimOptions {
     /// - `--color=current_bg:24`: Default scheme with custom current line background
     /// - `--color=dark,matched:#00FF00`: Green matched text on dark theme
     /// - `--color=fg:#FFFFFF,bg:#000000`: Custom white-on-black color scheme
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub color: Option<String>,
 
     /// Disable horizontal scroll
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub no_hscroll: bool,
 
     /// Keep the right end of the line visible on overflow
     ///
     /// Effective only when the query string is empty
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub keep_right: bool,
 
     /// Show the matched pattern at the line start
@@ -525,7 +547,7 @@ pub struct SkimOptions {
     /// string is empty. Was designed to skip showing starts of paths of rg/grep results.
     ///
     /// **Example**: `sk -i -c "rg {} --color=always" --skip-to-pattern '[^/]*:' --ansi`
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub skip_to_pattern: Option<String>,
 
     /// Do not clear previous line if the command returns an empty result
@@ -536,11 +558,11 @@ pub struct SkimOptions {
     /// This is not the default behavior because similar use cases for grep and rg have already been op‐
     /// timized where empty query results actually mean "empty" and previous results should be
     /// cleared.
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub no_clear_if_empty: bool,
 
     /// Do not clear items on start
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub no_clear_start: bool,
 
     /// Do not clear screen on exit
@@ -548,11 +570,11 @@ pub struct SkimOptions {
     /// Do not clear finder interface on exit. If skim was started in full screen mode, it will not switch back to the
     /// original  screen, so you'll have to manually run tput rmcup to return. This option can be used to avoid
     /// flickering of the screen when your application needs to start skim multiple times in order.
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub no_clear: bool,
 
     /// Show error message if command fails
-    #[arg(long, help_heading = "Interface")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Interface"))]
     pub show_cmd_error: bool,
 
     //  --- Layout ---
@@ -563,28 +585,28 @@ pub struct SkimOptions {
     /// *reverse: Display from the top of the screen
     ///
     /// *reverse-list: Display from the top of the screen, prompt at the bottom
-    #[arg(
+    #[cfg_attr(feature = "cli", arg(
         long,
         default_value = "default",
         value_parser = clap::builder::PossibleValuesParser::new(
             ["default", "reverse", "reverse-list"]
         ),
         help_heading = "Layout",
-    )]
+    ))]
     pub layout: String,
 
     /// Shorthand for reverse layout
-    #[arg(long, help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Layout"))]
     pub reverse: bool,
 
     /// Height of skim's window
     ///
     /// Can either be a row count or a percentage
-    #[arg(long, default_value = "100%", help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "100%", help_heading = "Layout"))]
     pub height: String,
 
     /// Disable height feature
-    #[arg(long, help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Layout"))]
     pub no_height: bool,
 
     /// Minimum height of skim's window
@@ -592,7 +614,7 @@ pub struct SkimOptions {
     /// Useful when the height is set as a percentage
     ///
     /// Ignored when `--height` is not specified
-    #[arg(long, default_value = "10", help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "10", help_heading = "Layout"))]
     pub min_height: String,
 
     /// Screen margin
@@ -610,24 +632,24 @@ pub struct SkimOptions {
     /// * T,R,B,L
     ///
     /// **Example**: 1,10%
-    #[arg(long, default_value = "0", help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "0", help_heading = "Layout"))]
     pub margin: String,
 
     /// Set prompt
-    #[arg(long, short, default_value = "> ", help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, short, default_value = "> ", help_heading = "Layout"))]
     pub prompt: String,
 
     /// Set prompt in command mode
-    #[arg(long, default_value = "c> ", help_heading = "Layout")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "c> ", help_heading = "Layout"))]
     pub cmd_prompt: String,
 
     //  --- Display ---
     /// Parse ANSI color codes in input strings
-    #[arg(long, help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Display"))]
     pub ansi: bool,
 
     /// Number of spaces that make up a tab
-    #[arg(long, default_value = "8", help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "8", help_heading = "Display"))]
     pub tabstop: usize,
 
     /// Set matching result count display position
@@ -635,15 +657,18 @@ pub struct SkimOptions {
     /// * hidden: do not display info
     /// * inline: display info in the same row as the input
     /// * default: display info in a dedicated row above the input
-    #[arg(long, help_heading = "Display", value_enum, default_value = "default")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long, help_heading = "Display", value_enum, default_value = "default")
+    )]
     pub info: InfoDisplay,
 
     /// Alias for --info=hidden
-    #[arg(long, help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Display"))]
     pub no_info: bool,
 
     /// Alias for --info=inline
-    #[arg(long, help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Display"))]
     pub inline_info: bool,
 
     /// Set header, displayed next to the info
@@ -651,14 +676,14 @@ pub struct SkimOptions {
     /// The  given  string  will  be printed as the sticky header. The lines are displayed in the
     /// given order from top to bottom regardless of `--layout` option, and  are  not  affected  by
     /// `--with-nth`. ANSI color codes are processed even when `--ansi` is not set.
-    #[arg(long, help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Display"))]
     pub header: Option<String>,
 
     /// Number of lines of the input treated as header
     ///
     /// The  first N lines of the input are treated as the sticky header. When `--with-nth` is set,
     /// the lines are transformed just like the other lines that follow.
-    #[arg(long, default_value = "0", help_heading = "Display")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "0", help_heading = "Display"))]
     pub header_lines: usize,
 
     //  --- History ---
@@ -668,11 +693,11 @@ pub struct SkimOptions {
     ///
     /// When enabled, CTRL-N and CTRL-P are automatically remapped
     /// to next-history and previous-history.
-    #[arg(long = "history", help_heading = "History")]
+    #[cfg_attr(feature = "cli", arg(long = "history", help_heading = "History"))]
     pub history_file: Option<String>,
 
     /// Maximum number of query history entries to keep
-    #[arg(long, default_value = "1000", help_heading = "History")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "1000", help_heading = "History"))]
     pub history_size: usize,
 
     /// Command history file
@@ -681,11 +706,11 @@ pub struct SkimOptions {
     ///
     /// When enabled, CTRL-N and CTRL-P are automatically remapped
     /// to next-history and previous-history.
-    #[arg(long = "cmd-history", help_heading = "History")]
+    #[cfg_attr(feature = "cli", arg(long = "cmd-history", help_heading = "History"))]
     pub cmd_history_file: Option<String>,
 
     /// Maximum number of query history entries to keep
-    #[arg(long, default_value = "1000", help_heading = "History")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "1000", help_heading = "History"))]
     pub cmd_history_size: usize,
 
     //  --- Preview ---
@@ -721,7 +746,7 @@ pub struct SkimOptions {
     ///
     /// Preview window will be updated even when there is no match for the current query if any of the placeholder ex‐
     /// pressions evaluates to a non-empty string.
-    #[arg(long, help_heading = "Preview")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Preview"))]
     pub preview: Option<String>,
 
     /// Preview window layout
@@ -756,16 +781,16 @@ pub struct SkimOptions {
     ///       --preview 'bat --style=numbers --color=always --highlight-line {2} {1}' \
     ///       --preview-window +{2}-/2
     /// ```
-    #[arg(long, default_value = "right:50%", help_heading = "Preview")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "right:50%", help_heading = "Preview"))]
     pub preview_window: String,
 
     //  --- Scripting ---
     /// Initial query
-    #[arg(long, short, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, short, help_heading = "Scripting"))]
     pub query: Option<String>,
 
     /// Initial query in interactive mode
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub cmd_query: Option<String>,
 
     /// [Deprecated: Use `--bind=<key>:accept(<key>)` instead] Comma separated list of keys used to complete skim
@@ -777,35 +802,35 @@ pub struct SkimOptions {
     /// list.
     ///
     /// **Example**: `sk --expect=ctrl-v,ctrl-t,alt-s --expect=f1,f2,~,@`
-    #[arg(long, help_heading = "Scripting", value_delimiter = ',')]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting", value_delimiter = ','))]
     pub expect: Vec<String>,
 
     /// Read input delimited by ASCII NUL(\\0) characters
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub read0: bool,
 
     /// Print output delimited by ASCII NUL(\\0) characters
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub print0: bool,
 
     /// Print the query as the first line
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub print_query: bool,
 
     /// Print the command as the first line (after print-query)
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub print_cmd: bool,
 
     /// Print the command as the first line (after print-cmd)
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub print_score: bool,
 
     /// Automatically select the match if there is only one
-    #[arg(long, short = '1', help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, short = '1', help_heading = "Scripting"))]
     pub select_1: bool,
 
     /// Automatically exit when no match is left
-    #[arg(long, short = '0', help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, short = '0', help_heading = "Scripting"))]
     pub exit_0: bool,
 
     /// Synchronous search for multi-staged filtering
@@ -814,32 +839,32 @@ pub struct SkimOptions {
     /// skim will launch ncurses finder only after the input stream is complete.
     ///
     /// **Example**: `sk --multi | sk --sync`
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub sync: bool,
 
     /// Pre-select the first n items in multi-selection mode
-    #[arg(long, default_value = "0", help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "0", help_heading = "Scripting"))]
     pub pre_select_n: usize,
 
     /// Pre-select the matched items in multi-selection mode
     ///
     /// Check the doc for the detailed syntax:
     /// https://docs.rs/regex/1.4.1/regex/
-    #[arg(long, default_value = "", help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "", help_heading = "Scripting"))]
     pub pre_select_pat: String,
 
     /// Pre-select the items separated by newline character
     ///
     /// **Example**: `item1\nitem2`
-    #[arg(long, default_value = "", help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, default_value = "", help_heading = "Scripting"))]
     pub pre_select_items: String,
 
     /// Pre-select the items read from this file
-    #[arg(long, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Scripting"))]
     pub pre_select_file: Option<String>,
 
     /// Query for filter mode
-    #[arg(long, short, help_heading = "Scripting")]
+    #[cfg_attr(feature = "cli", arg(long, short, help_heading = "Scripting"))]
     pub filter: Option<String>,
 
     /// Generate shell completion script
@@ -852,8 +877,11 @@ pub struct SkimOptions {
     /// Supported shells: bash, zsh, fish, powershell, elvish
     ///
     /// Note: While PowerShell completions are supported, Windows is not supported for now.
-    #[arg(long, value_name = "SHELL", help_heading = "Scripting")]
-    #[arg(value_enum)]
+    #[cfg(feature = "cli")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long, value_name = "SHELL", help_heading = "Scripting", value_enum)
+    )]
     pub shell: Option<clap_complete::Shell>,
 
     /// Run in a tmux popup
@@ -870,65 +898,74 @@ pub struct SkimOptions {
     ///
     /// Note: env vars are only passed to the tmux command if they are either `PATH` or prefixed with
     /// `RUST` or `SKIM`
-    #[arg(long, help_heading = "Display", default_missing_value = "center,50%", num_args=0..)]
+    #[cfg_attr(feature = "cli", arg(long, help_heading = "Display", default_missing_value = "center,50%", num_args=0..))]
     pub tmux: Option<String>,
 
     /// Reserved for later use
-    #[arg(short = 'x', long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(short = 'x', long, hide = true, help_heading = "Reserved for later use")
+    )]
     pub extended: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub literal: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub cycle: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, default_value = "10", help_heading = "Reserved for later use")]
+    #[cfg_attr(
+        feature = "cli",
+        arg(long, hide = true, default_value = "10", help_heading = "Reserved for later use")
+    )]
     pub hscroll_off: usize,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub filepath_word: bool,
 
     /// Reserved for later use
-    #[arg(
-        long,
-        hide = true,
-        default_value = "abcdefghijklmnopqrstuvwxyz",
-        help_heading = "Reserved for later use"
+    #[cfg_attr(
+        feature = "cli",
+        arg(
+            long,
+            hide = true,
+            default_value = "abcdefghijklmnopqrstuvwxyz",
+            help_heading = "Reserved for later use"
+        )
     )]
     pub jump_labels: String,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use", default_missing_value="Hi", num_args=0..=1)]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use", default_missing_value="Hi", num_args=0..=1))]
     pub border: Option<String>,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub no_bold: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub pointer: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub marker: bool,
 
     /// Reserved for later use
-    #[arg(long, hide = true, help_heading = "Reserved for later use")]
+    #[cfg_attr(feature = "cli", arg(long, hide = true, help_heading = "Reserved for later use"))]
     pub phony: bool,
 
-    #[clap(skip = Rc::new(RefCell::new(SkimItemReader::default())) as Rc<RefCell<dyn CommandCollector>>)]
+    #[cfg_attr(feature = "cli", clap(skip = Rc::new(RefCell::new(SkimItemReader::default())) as Rc<RefCell<dyn CommandCollector>>))]
     pub cmd_collector: Rc<RefCell<dyn CommandCollector>>,
-    #[clap(skip)]
+    #[cfg_attr(feature = "cli", clap(skip))]
     pub query_history: Vec<String>,
-    #[clap(skip)]
+    #[cfg_attr(feature = "cli", clap(skip))]
     pub cmd_history: Vec<String>,
-    #[clap(skip)]
+    #[cfg_attr(feature = "cli", clap(skip))]
     pub selector: Option<Rc<dyn Selector>>,
     /// Preview Callback
     ///
@@ -936,13 +973,96 @@ pub struct SkimOptions {
     ///
     /// The function will take a `Vec<Arc<dyn SkimItem>>>` containing the currently selected items
     /// and return a Vec<String> with the lines to display in UTF-8
-    #[clap(skip)]
+    #[cfg_attr(feature = "cli", clap(skip))]
     pub preview_fn: Option<PreviewCallback>,
 }
 
 impl Default for SkimOptions {
     fn default() -> Self {
-        Self::parse_from::<_, &str>([])
+        Self {
+            tac: Default::default(),
+            min_query_length: Default::default(),
+            no_sort: Default::default(),
+            tiebreak: vec![RankCriteria::Score, RankCriteria::Begin, RankCriteria::End],
+            nth: Default::default(),
+            with_nth: Default::default(),
+            delimiter: String::from(r"[\t\n ]+"),
+            exact: Default::default(),
+            regex: Default::default(),
+            algorithm: Default::default(),
+            case: Default::default(),
+            bind: Default::default(),
+            multi: Default::default(),
+            no_multi: Default::default(),
+            no_mouse: Default::default(),
+            cmd: Default::default(),
+            interactive: Default::default(),
+            replstr: String::from("{}"),
+            color: Default::default(),
+            no_hscroll: Default::default(),
+            keep_right: Default::default(),
+            skip_to_pattern: Default::default(),
+            no_clear_if_empty: Default::default(),
+            no_clear_start: Default::default(),
+            no_clear: Default::default(),
+            show_cmd_error: Default::default(),
+            layout: String::from("default"),
+            reverse: Default::default(),
+            height: String::from("100%"),
+            no_height: Default::default(),
+            min_height: String::from("10"),
+            margin: Default::default(),
+            prompt: String::from("> "),
+            cmd_prompt: String::from("c> "),
+            ansi: Default::default(),
+            tabstop: 8,
+            info: Default::default(),
+            no_info: Default::default(),
+            inline_info: Default::default(),
+            header: Default::default(),
+            header_lines: Default::default(),
+            history_file: Default::default(),
+            history_size: 1000,
+            cmd_history_file: Default::default(),
+            cmd_history_size: 1000,
+            preview: Default::default(),
+            preview_window: String::from("right:50%"),
+            query: Default::default(),
+            cmd_query: Default::default(),
+            expect: Default::default(),
+            read0: Default::default(),
+            print0: Default::default(),
+            print_query: Default::default(),
+            print_cmd: Default::default(),
+            print_score: Default::default(),
+            select_1: Default::default(),
+            exit_0: Default::default(),
+            sync: Default::default(),
+            pre_select_n: Default::default(),
+            pre_select_pat: Default::default(),
+            pre_select_items: Default::default(),
+            pre_select_file: Default::default(),
+            filter: Default::default(),
+            #[cfg(feature = "cli")]
+            shell: Default::default(),
+            tmux: Default::default(),
+            extended: Default::default(),
+            literal: Default::default(),
+            cycle: Default::default(),
+            hscroll_off: 10,
+            filepath_word: Default::default(),
+            jump_labels: String::from("abcdefghijklmnopqrstuvwxyz"),
+            border: Default::default(),
+            no_bold: Default::default(),
+            pointer: Default::default(),
+            marker: Default::default(),
+            phony: Default::default(),
+            cmd_collector: Rc::new(RefCell::new(SkimItemReader::default())) as Rc<RefCell<dyn CommandCollector>>,
+            query_history: Default::default(),
+            cmd_history: Default::default(),
+            selector: Default::default(),
+            preview_fn: Default::default(),
+        }
     }
 }
 
