@@ -7,10 +7,10 @@ pub use crate::options::{SkimOptions, SkimOptionsBuilder};
 pub use crate::output::SkimOutput;
 pub use crate::previewer::PreviewCallback;
 pub use crate::*;
-pub use crossbeam::channel::{bounded, unbounded, Receiver, Sender};
+pub use crossbeam::channel::{Receiver, Sender, bounded, unbounded};
+pub use skim_tuikit::event::Key;
 pub use std::borrow::Cow;
 pub use std::cell::RefCell;
 pub use std::rc::Rc;
-pub use std::sync::atomic::{AtomicUsize, Ordering};
 pub use std::sync::Arc;
-pub use tuikit::event::Key;
+pub use std::sync::atomic::{AtomicUsize, Ordering};
